=== modified file 'NEWS'
--- NEWS	2009-02-26 20:10:17 +0000
+++ NEWS	2009-03-01 20:21:01 +0000
@@ -5,7 +5,7 @@
 ---------------
     - Loggerhead now serves bzr branches over HTTP and exposes the URL to
       branch them. (Jonathan Lange)
-    
+
     - Leading blank lines in commit messages no longer result in an empty
       summary. (Colin Watson)
 

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2009-02-11 03:23:45 +0000
+++ loggerhead/controllers/__init__.py	2009-03-01 20:57:52 +0000
@@ -40,7 +40,7 @@
     def flush(self):
         chunk = ''.join(self.buf)
         chunk = re.sub(r'\s*\n\s*', '\n', chunk)
-        chunk = re.sub(r'[ \t]+', ' ', chunk)
+        #chunk = re.sub(r'[ \t]+', ' ', chunk)
         self.bytes_saved += self.buflen - len(chunk)
         self.writefunc(chunk)
         self.buf = []

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2009-03-01 19:21:18 +0000
+++ loggerhead/controllers/annotate_ui.py	2009-03-02 00:10:26 +0000
@@ -26,7 +26,7 @@
 from paste.httpexceptions import HTTPBadRequest, HTTPServerError
 
 from loggerhead.controllers import TemplatedBranchView
-from loggerhead.highlight import pygments_highlight
+from loggerhead.highlight import highlight
 from loggerhead import util
 
 
@@ -41,22 +41,20 @@
 
         file_revid = self._history.get_inventory(revid)[file_id].revision
         tree = self._history._branch.repository.revision_tree(file_revid)
-	
-	file_name = os.path.basename(self._history.get_path(revid, file_id))
-	hl_lines = None
+
+        file_name = os.path.basename(self._history.get_path(revid, file_id))
 
         try:
-	    file_lines = tree.get_file_lines(file_id)
-
+            file_lines = tree.get_file_lines(file_id)
             bzrlib.textfile.check_text_lines(file_lines)
-
-	    hl_lines = pygments_highlight(file_name, ''.join(file_lines))
         except bzrlib.errors.BinaryFile:
                 # bail out; this isn't displayable text
                 yield util.Container(parity=0, lineno=1, status='same',
                                      text='(This is a binary file.)',
                                      change=util.Container())
         else:
+            hl_lines = highlight(file_name, ''.join(file_lines))
+
             change_cache = {}
 
             last_line_revid = None

=== modified file 'loggerhead/highlight.py'
--- loggerhead/highlight.py	2009-03-01 19:24:21 +0000
+++ loggerhead/highlight.py	2009-03-02 00:10:26 +0000
@@ -16,7 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-from pygments import highlight
+from pygments import highlight as _highlight_func
 from pygments.lexers import guess_lexer, guess_lexer_for_filename, TextLexer
 from pygments.formatters import HtmlFormatter
 from pygments.util import ClassNotFound
@@ -26,47 +26,31 @@
 DEFAULT_PYGMENT_STYLE = 'colorful'
 
 
-def pygments_highlight(path, text, style=DEFAULT_PYGMENT_STYLE):
-    """ 
-    Returns a list of highlighted (i.e. HTML formatted) strings and it replaces
-    spaces outside of HTML tags with nonbreaking spaces to maintain
+def highlight(path, text, style=DEFAULT_PYGMENT_STYLE):
+    """
+    Returns a list of highlighted (i.e. HTML formatted) strings and it
+    replaces initial spaces with nonbreaking spaces to maintain
     indentation.
     """
 
-    formatter = PygmentsHtmlFormatter(style=style)
-	
+    formatter = HtmlFormatter(style=style, nowrap=True, classprefix='pyg-')
+
     encoding = 'utf-8'
     try:
-	text = text.decode(encoding)
+        text = text.decode(encoding)
     except UnicodeDecodeError:
-	text = text.decode(encoding)
-	encoding = 'iso-8859-15'
+        encoding = 'iso-8859-15'
+        text = text.decode(encoding)
 
     try:
-	lexer = guess_lexer_for_filename(path, text, encoding=encoding)
+        lexer = guess_lexer_for_filename(path, text, encoding=encoding)
     except (ClassNotFound, ValueError):
-	try: 
-	    lexer = guess_lexer(text, encoding=encoding)
-	except (ClassNotFound, ValueError):
-	    lexer = TextLexer(encoding=encoding)
+        try:
+            lexer = guess_lexer(text, encoding=encoding)
+        except (ClassNotFound, ValueError):
+            lexer = TextLexer(encoding=encoding)
 
-    hl_lines = highlight(text, lexer, formatter).split('\n')
-    hl_lines = [ util.fix_whitespace(line) for line in hl_lines ]
+    hl_lines = _highlight_func(text, lexer, formatter).split('\n')
+#    hl_lines = [util.fix_whitespace(line) for line in hl_lines]
 
     return hl_lines
-
-
-class PygmentsHtmlFormatter(HtmlFormatter):
-    """
-    Custom HTML formatter to avoid default <div> and <pre> blocks.
-    """
-
-    def wrap(self, source, outfile):
-	return self._wrap_code(source)
-
-    def _wrap_code(self, source):
-	yield 0, ''
-	for i, t in source:
-	    yield i, t
-	    
-	yield 0, ''

=== modified file 'loggerhead/static/css/annotate.css'
--- loggerhead/static/css/annotate.css	2008-08-05 19:44:50 +0000
+++ loggerhead/static/css/annotate.css	2009-03-01 20:57:52 +0000
@@ -21,7 +21,9 @@
 }
 .annoLine, .annoCont {
 	font:normal 12px/normal monospace;
+        whitespace: pre;
 }
+.annoCont pre { margin: 0; }
 .annoLine {
 	text-align:right;
 }

=== modified file 'loggerhead/static/css/highlight.css'
--- loggerhead/static/css/highlight.css	2009-02-26 14:10:58 +0000
+++ loggerhead/static/css/highlight.css	2009-03-01 20:16:18 +0000
@@ -1,59 +1,59 @@
-.c { color: #808080 } /* Comment */
-.err { color: #F00000; background-color: #F0A0A0 } /* Error */
-.k { color: #008000; font-weight: bold } /* Keyword */
-.o { color: #303030 } /* Operator */
-.cm { color: #808080 } /* Comment.Multiline */
-.cp { color: #507090 } /* Comment.Preproc */
-.c1 { color: #808080 } /* Comment.Single */
-.cs { color: #cc0000; font-weight: bold } /* Comment.Special */
-.gd { color: #A00000 } /* Generic.Deleted */
-.ge { font-style: italic } /* Generic.Emph */
-.gr { color: #FF0000 } /* Generic.Error */
-.gh { color: #000080; font-weight: bold } /* Generic.Heading */
-.gi { color: #00A000 } /* Generic.Inserted */
-.go { color: #808080 } /* Generic.Output */
-.gp { color: #c65d09; font-weight: bold } /* Generic.Prompt */
-.gs { font-weight: bold } /* Generic.Strong */
-.gu { color: #800080; font-weight: bold } /* Generic.Subheading */
-.gt { color: #0040D0 } /* Generic.Traceback */
-.kc { color: #008000; font-weight: bold } /* Keyword.Constant */
-.kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
-.kp { color: #003080; font-weight: bold } /* Keyword.Pseudo */
-.kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
-.kt { color: #303090; font-weight: bold } /* Keyword.Type */
-.m { color: #6000E0; font-weight: bold } /* Literal.Number */
-.s { background-color: #fff0f0 } /* Literal.String */
-.na { color: #0000C0 } /* Name.Attribute */
-.nb { color: #007020 } /* Name.Builtin */
-.nc { color: #B00060; font-weight: bold } /* Name.Class */
-.no { color: #003060; font-weight: bold } /* Name.Constant */
-.nd { color: #505050; font-weight: bold } /* Name.Decorator */
-.ni { color: #800000; font-weight: bold } /* Name.Entity */
-.ne { color: #F00000; font-weight: bold } /* Name.Exception */
-.nf { color: #0060B0; font-weight: bold } /* Name.Function */
-.nl { color: #907000; font-weight: bold } /* Name.Label */
-.nn { color: #0e84b5; font-weight: bold } /* Name.Namespace */
-.nt { color: #007000 } /* Name.Tag */
-.nv { color: #906030 } /* Name.Variable */
-.ow { color: #000000; font-weight: bold } /* Operator.Word */
-.w { color: #bbbbbb } /* Text.Whitespace */
-.mf { color: #6000E0; font-weight: bold } /* Literal.Number.Float */
-.mh { color: #005080; font-weight: bold } /* Literal.Number.Hex */
-.mi { color: #0000D0; font-weight: bold } /* Literal.Number.Integer */
-.mo { color: #4000E0; font-weight: bold } /* Literal.Number.Oct */
-.sb { background-color: #fff0f0 } /* Literal.String.Backtick */
-.sc { color: #0040D0 } /* Literal.String.Char */
-.sd { color: #D04020 } /* Literal.String.Doc */
-.s2 { background-color: #fff0f0 } /* Literal.String.Double */
-.se { color: #606060; font-weight: bold; background-color: #fff0f0 } /* Literal.String.Escape */
-.sh { background-color: #fff0f0 } /* Literal.String.Heredoc */
-.si { background-color: #e0e0e0 } /* Literal.String.Interpol */
-.sx { color: #D02000; background-color: #fff0f0 } /* Literal.String.Other */
-.sr { color: #000000; background-color: #fff0ff } /* Literal.String.Regex */
-.s1 { background-color: #fff0f0 } /* Literal.String.Single */
-.ss { color: #A06000 } /* Literal.String.Symbol */
-.bp { color: #007020 } /* Name.Builtin.Pseudo */
-.vc { color: #306090 } /* Name.Variable.Class */
-.vg { color: #d07000; font-weight: bold } /* Name.Variable.Global */
-.vi { color: #3030B0 } /* Name.Variable.Instance */
-.il { color: #0000D0; font-weight: bold } /* Literal.Number.Integer.Long */
+.pyg-c { color: #808080 } /* Comment */
+.pyg-err { color: #F00000; background-color: #F0A0A0 } /* Error */
+.pyg-k { color: #008000; font-weight: bold } /* Keyword */
+.pyg-o { color: #303030 } /* Operator */
+.pyg-cm { color: #808080 } /* Comment.Multiline */
+.pyg-cp { color: #507090 } /* Comment.Preproc */
+.pyg-c1 { color: #808080 } /* Comment.Single */
+.pyg-cs { color: #cc0000; font-weight: bold } /* Comment.Special */
+.pyg-gd { color: #A00000 } /* Generic.Deleted */
+.pyg-ge { font-style: italic } /* Generic.Emph */
+.pyg-gr { color: #FF0000 } /* Generic.Error */
+.pyg-gh { color: #000080; font-weight: bold } /* Generic.Heading */
+.pyg-gi { color: #00A000 } /* Generic.Inserted */
+.pyg-go { color: #808080 } /* Generic.Output */
+.pyg-gp { color: #c65d09; font-weight: bold } /* Generic.Prompt */
+.pyg-gs { font-weight: bold } /* Generic.Strong */
+.pyg-gu { color: #800080; font-weight: bold } /* Generic.Subheading */
+.pyg-gt { color: #0040D0 } /* Generic.Traceback */
+.pyg-kc { color: #008000; font-weight: bold } /* Keyword.Constant */
+.pyg-kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
+.pyg-kp { color: #003080; font-weight: bold } /* Keyword.Pseudo */
+.pyg-kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
+.pyg-kt { color: #303090; font-weight: bold } /* Keyword.Type */
+.pyg-m { color: #6000E0; font-weight: bold } /* Literal.Number */
+.pyg-s { background-color: #fff0f0 } /* Literal.String */
+.pyg-na { color: #0000C0 } /* Name.Attribute */
+.pyg-nb { color: #007020 } /* Name.Builtin */
+.pyg-nc { color: #B00060; font-weight: bold } /* Name.Class */
+.pyg-no { color: #003060; font-weight: bold } /* Name.Constant */
+.pyg-nd { color: #505050; font-weight: bold } /* Name.Decorator */
+.pyg-ni { color: #800000; font-weight: bold } /* Name.Entity */
+.pyg-ne { color: #F00000; font-weight: bold } /* Name.Exception */
+.pyg-nf { color: #0060B0; font-weight: bold } /* Name.Function */
+.pyg-nl { color: #907000; font-weight: bold } /* Name.Label */
+.pyg-nn { color: #0e84b5; font-weight: bold } /* Name.Namespace */
+.pyg-nt { color: #007000 } /* Name.Tag */
+.pyg-nv { color: #906030 } /* Name.Variable */
+.pyg-ow { color: #000000; font-weight: bold } /* Operator.Word */
+.pyg-w { color: #bbbbbb } /* Text.Whitespace */
+.pyg-mf { color: #6000E0; font-weight: bold } /* Literal.Number.Float */
+.pyg-mh { color: #005080; font-weight: bold } /* Literal.Number.Hex */
+.pyg-mi { color: #0000D0; font-weight: bold } /* Literal.Number.Integer */
+.pyg-mo { color: #4000E0; font-weight: bold } /* Literal.Number.Oct */
+.pyg-sb { background-color: #fff0f0 } /* Literal.String.Backtick */
+.pyg-sc { color: #0040D0 } /* Literal.String.Char */
+.pyg-sd { color: #D04020 } /* Literal.String.Doc */
+.pyg-s2 { background-color: #fff0f0 } /* Literal.String.Double */
+.pyg-se { color: #606060; font-weight: bold; background-color: #fff0f0 } /* Literal.String.Escape */
+.pyg-sh { background-color: #fff0f0 } /* Literal.String.Heredoc */
+.pyg-si { background-color: #e0e0e0 } /* Literal.String.Interpol */
+.pyg-sx { color: #D02000; background-color: #fff0f0 } /* Literal.String.Other */
+.pyg-sr { color: #000000; background-color: #fff0ff } /* Literal.String.Regex */
+.pyg-s1 { background-color: #fff0f0 } /* Literal.String.Single */
+.pyg-ss { color: #A06000 } /* Literal.String.Symbol */
+.pyg-bp { color: #007020 } /* Name.Builtin.Pseudo */
+.pyg-vc { color: #306090 } /* Name.Variable.Class */
+.pyg-vg { color: #d07000; font-weight: bold } /* Name.Variable.Global */
+.pyg-vi { color: #3030B0 } /* Name.Variable.Instance */
+.pyg-il { color: #0000D0; font-weight: bold } /* Literal.Number.Integer.Long */

=== modified file 'loggerhead/templates/annotate.pt'
--- loggerhead/templates/annotate.pt	2009-03-01 19:29:33 +0000
+++ loggerhead/templates/annotate.pt	2009-03-02 00:10:26 +0000
@@ -67,7 +67,7 @@
                  tal:attributes="href python:url(['/revision', line.change.revno], clear=1);
                                  title python:'%s by %s, on %s (%s)'%(line.change.revno, util.hide_email(line.change.author), line.change.date.strftime('%d %b %Y %H:%M'), util.date_time(line.change.date))"></a>
             </td>
-            <td class="annoCont" tal:content="structure line/text"></td>
+            <td class="annoCont"><pre tal:content="structure line/text"></pre></td>
           </tr>
         </table>
       </div>

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2009-02-26 17:50:46 +0000
+++ loggerhead/util.py	2009-03-01 20:57:52 +0000
@@ -241,28 +241,6 @@
     return s.expandtabs().replace(' ', NONBREAKING_SPACE)
 
 
-def fix_whitespace(s):
-    """
-    Replace spaces outside of HTML tags with nonbreaking spaces 
-    """
-
-    ns = ''
-    outside_tag = True	# Whether or not we are outside of a HTML tag
-
-    for c in s.expandtabs():
-	if outside_tag:
-	    if c == '<':
-		outside_tag = False
-	    elif c == ' ':
-		c = NONBREAKING_SPACE
-	else: # Inside tag
-	    if c == '>':
-		outside_tag = True
-	ns += c
-
-    return ns
-
-
 def fake_permissions(kind, executable):
     # fake up unix-style permissions given only a "kind" and executable bit
     if kind == 'directory':

